==> cellartracker-0.6.0.tar.gz: cellartracker-0.6.0/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['requests'],

setup_requirements = [ ]

test_requirements = ['requests_mock']

setup(
    author="Mathieu Rul",
    author_email='mathroule@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Python package to export CellarTracker data.",
    entry_points={
        'console_scripts': [
            'cellartracker=cellartracker.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='cellartracker',
    name='cellartracker',
    packages=find_packages(include=['cellartracker', 'cellartracker.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/mathroule/cellartracker',
    version='0.6.0',
    zip_safe=False,
)

==> cellartracker-1.0.0.tar.gz: cellartracker-1.0.0/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = ['requests'],

setup_requirements = [ ]

test_requirements = ['requests_mock']

setup(
    author="Mathieu Rul",
    author_email='mathieu.rul@gmail.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Python package to export CellarTracker data.",
    entry_points={
        'console_scripts': [
            'cellartracker=cellartracker.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='cellartracker',
    name='cellartracker',
    packages=find_packages(include=['cellartracker', 'cellartracker.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/mathroule/cellartracker',
    version='1.0.0',
    zip_safe=False,
)
